/****************************************************************************
** Meta object code from reading C++ file 'component.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kglobalacceld-6.7.0/src/component.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'component.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9ComponentE_t {};
} // unnamed namespace

template <> constexpr inline auto Component::qt_create_metaobjectdata<qt_meta_tag_ZN9ComponentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Component",
        "D-Bus Interface",
        "org.kde.kglobalaccel.Component",
        "globalShortcutPressed",
        "",
        "componentUnique",
        "shortcutUnique",
        "timestamp",
        "globalShortcutRepeated",
        "globalShortcutReleased",
        "cleanUp",
        "isActive",
        "shortcutNames",
        "context",
        "allShortcutInfos",
        "QList<KGlobalShortcutInfo>",
        "getShortcutContexts",
        "emitGlobalShortcutEvent",
        "GlobalShortcut",
        "shortcut",
        "ShortcutKeyState",
        "state",
        "invokeShortcut",
        "shortcutName",
        "friendlyName",
        "uniqueName"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'globalShortcutPressed'
        QtMocHelpers::SignalData<void(const QString &, const QString &, qlonglong)>(3, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 6 }, { QMetaType::LongLong, 7 },
        }}),
        // Signal 'globalShortcutRepeated'
        QtMocHelpers::SignalData<void(const QString &, const QString &, qlonglong)>(8, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 6 }, { QMetaType::LongLong, 7 },
        }}),
        // Signal 'globalShortcutReleased'
        QtMocHelpers::SignalData<void(const QString &, const QString &, qlonglong)>(9, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 6 }, { QMetaType::LongLong, 7 },
        }}),
        // Slot 'cleanUp'
        QtMocHelpers::SlotData<bool()>(10, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'isActive'
        QtMocHelpers::SlotData<bool() const>(11, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'shortcutNames'
        QtMocHelpers::SlotData<QStringList(const QString &) const>(12, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'shortcutNames'
        QtMocHelpers::SlotData<QStringList() const>(12, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::QStringList),
        // Slot 'allShortcutInfos'
        QtMocHelpers::SlotData<QList<KGlobalShortcutInfo>(const QString &) const>(14, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 15, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'allShortcutInfos'
        QtMocHelpers::SlotData<QList<KGlobalShortcutInfo>() const>(14, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, 0x80000000 | 15),
        // Slot 'getShortcutContexts'
        QtMocHelpers::SlotData<QStringList() const>(16, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList),
        // Slot 'emitGlobalShortcutEvent'
        QtMocHelpers::SlotData<void(const GlobalShortcut &, ShortcutKeyState)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { 0x80000000 | 20, 21 },
        }}),
        // Slot 'invokeShortcut'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(22, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 23 }, { QMetaType::QString, 13 },
        }}),
        // Slot 'invokeShortcut'
        QtMocHelpers::SlotData<void(const QString &)>(22, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'friendlyName'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'uniqueName'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Component, qt_meta_tag_ZN9ComponentE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Component::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9ComponentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9ComponentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9ComponentE_t>.metaTypes,
    nullptr
} };

void Component::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Component *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->globalShortcutPressed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[3]))); break;
        case 1: _t->globalShortcutRepeated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[3]))); break;
        case 2: _t->globalShortcutReleased((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[3]))); break;
        case 3: { bool _r = _t->cleanUp();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->isActive();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { QStringList _r = _t->shortcutNames((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 6: { QStringList _r = _t->shortcutNames();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 7: { QList<KGlobalShortcutInfo> _r = _t->allShortcutInfos((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QList<KGlobalShortcutInfo>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QList<KGlobalShortcutInfo> _r = _t->allShortcutInfos();
            if (_a[0]) *reinterpret_cast<QList<KGlobalShortcutInfo>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QStringList _r = _t->getShortcutContexts();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->emitGlobalShortcutEvent((*reinterpret_cast<std::add_pointer_t<GlobalShortcut>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ShortcutKeyState>>(_a[2]))); break;
        case 11: _t->invokeShortcut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 12: _t->invokeShortcut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Component::*)(const QString & , const QString & , qlonglong )>(_a, &Component::globalShortcutPressed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Component::*)(const QString & , const QString & , qlonglong )>(_a, &Component::globalShortcutRepeated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Component::*)(const QString & , const QString & , qlonglong )>(_a, &Component::globalShortcutReleased, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->friendlyName(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->uniqueName(); break;
        default: break;
        }
    }
}

const QMetaObject *Component::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Component::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9ComponentE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Component::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void Component::globalShortcutPressed(const QString & _t1, const QString & _t2, qlonglong _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void Component::globalShortcutRepeated(const QString & _t1, const QString & _t2, qlonglong _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void Component::globalShortcutReleased(const QString & _t1, const QString & _t2, qlonglong _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
