/****************************************************************************
** Meta object code from reading C++ file 'kglobalacceld.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kglobalacceld-6.7.0/src/kglobalacceld.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#include <QtCore/QSet>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kglobalacceld.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13KGlobalAccelDE_t {};
} // unnamed namespace

template <> constexpr inline auto KGlobalAccelD::qt_create_metaobjectdata<qt_meta_tag_ZN13KGlobalAccelDE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KGlobalAccelD",
        "D-Bus Interface",
        "org.kde.KGlobalAccel",
        "yourShortcutGotChanged",
        "",
        "actionId",
        "QList<int>",
        "newKeys",
        "yourShortcutsChanged",
        "QSet<QKeySequence>",
        "allComponents",
        "QList<QDBusObjectPath>",
        "allMainComponents",
        "QList<QStringList>",
        "allActionsForComponent",
        "action",
        "key",
        "actionList",
        "QKeySequence",
        "shortcut",
        "shortcutKeys",
        "defaultShortcut",
        "defaultShortcutKeys",
        "getComponent",
        "QDBusObjectPath",
        "componentUnique",
        "setShortcut",
        "keys",
        "flags",
        "setShortcutKeys",
        "setForeignShortcut",
        "setForeignShortcutKeys",
        "setInactive",
        "doRegister",
        "unRegister",
        "activateGlobalShortcutContext",
        "component",
        "context",
        "getGlobalShortcutsByKey",
        "QList<KGlobalShortcutInfo>",
        "globalShortcutsByKey",
        "KGlobalAccel::MatchType",
        "type",
        "isGlobalShortcutAvailable",
        "globalShortcutAvailable",
        "unregister",
        "shortcutUnique",
        "blockGlobalShortcuts",
        "SetShortcutFlag",
        "SetPresent",
        "NoAutoloading",
        "IsDefault",
        "SetShortcutFlags"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'yourShortcutGotChanged'
        QtMocHelpers::SignalData<void(const QStringList &, const QList<int> &)>(3, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QStringList, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Signal 'yourShortcutsChanged'
        QtMocHelpers::SignalData<void(const QStringList &, const QSet<QKeySequence> &)>(8, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QStringList, 5 }, { 0x80000000 | 9, 7 },
        }}),
        // Slot 'allComponents'
        QtMocHelpers::SlotData<QList<QDBusObjectPath>() const>(10, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 11),
        // Slot 'allMainComponents'
        QtMocHelpers::SlotData<QList<QStringList>() const>(12, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 13),
        // Slot 'allActionsForComponent'
        QtMocHelpers::SlotData<QList<QStringList>(const QStringList &) const>(14, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 13, {{
            { QMetaType::QStringList, 5 },
        }}),
        // Slot 'action'
        QtMocHelpers::SlotData<QStringList(int) const>(15, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'actionList'
        QtMocHelpers::SlotData<QStringList(const QKeySequence &) const>(17, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList, {{
            { 0x80000000 | 18, 16 },
        }}),
        // Slot 'shortcut'
        QtMocHelpers::SlotData<QList<int>(const QStringList &) const>(19, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 6, {{
            { QMetaType::QStringList, 5 },
        }}),
        // Slot 'shortcutKeys'
        QtMocHelpers::SlotData<QSet<QKeySequence>(const QStringList &) const>(20, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 9, {{
            { QMetaType::QStringList, 5 },
        }}),
        // Slot 'defaultShortcut'
        QtMocHelpers::SlotData<QList<int>(const QStringList &) const>(21, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 6, {{
            { QMetaType::QStringList, 5 },
        }}),
        // Slot 'defaultShortcutKeys'
        QtMocHelpers::SlotData<QSet<QKeySequence>(const QStringList &) const>(22, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 9, {{
            { QMetaType::QStringList, 5 },
        }}),
        // Slot 'getComponent'
        QtMocHelpers::SlotData<QDBusObjectPath(const QString &) const>(23, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 24, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'setShortcut'
        QtMocHelpers::SlotData<QList<int>(const QStringList &, const QList<int> &, uint)>(26, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 6, {{
            { QMetaType::QStringList, 5 }, { 0x80000000 | 6, 27 }, { QMetaType::UInt, 28 },
        }}),
        // Slot 'setShortcutKeys'
        QtMocHelpers::SlotData<QSet<QKeySequence>(const QStringList &, const QSet<QKeySequence> &, uint)>(29, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 9, {{
            { QMetaType::QStringList, 5 }, { 0x80000000 | 9, 27 }, { QMetaType::UInt, 28 },
        }}),
        // Slot 'setForeignShortcut'
        QtMocHelpers::SlotData<void(const QStringList &, const QList<int> &)>(30, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QStringList, 5 }, { 0x80000000 | 6, 27 },
        }}),
        // Slot 'setForeignShortcutKeys'
        QtMocHelpers::SlotData<void(const QStringList &, const QSet<QKeySequence> &)>(31, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QStringList, 5 }, { 0x80000000 | 9, 27 },
        }}),
        // Slot 'setInactive'
        QtMocHelpers::SlotData<void(const QStringList &)>(32, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QStringList, 5 },
        }}),
        // Slot 'doRegister'
        QtMocHelpers::SlotData<void(const QStringList &)>(33, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QStringList, 5 },
        }}),
        // Slot 'unRegister'
        QtMocHelpers::SlotData<void(const QStringList &)>(34, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QStringList, 5 },
        }}),
        // Slot 'activateGlobalShortcutContext'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(35, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 36 }, { QMetaType::QString, 37 },
        }}),
        // Slot 'getGlobalShortcutsByKey'
        QtMocHelpers::SlotData<QList<KGlobalShortcutInfo>(int) const>(38, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 39, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'globalShortcutsByKey'
        QtMocHelpers::SlotData<QList<KGlobalShortcutInfo>(const QKeySequence &, KGlobalAccel::MatchType) const>(40, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 39, {{
            { 0x80000000 | 18, 16 }, { 0x80000000 | 41, 42 },
        }}),
        // Slot 'isGlobalShortcutAvailable'
        QtMocHelpers::SlotData<bool(int, const QString &) const>(43, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Int, 16 }, { QMetaType::QString, 36 },
        }}),
        // Slot 'globalShortcutAvailable'
        QtMocHelpers::SlotData<bool(const QKeySequence &, const QString &) const>(44, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { 0x80000000 | 18, 16 }, { QMetaType::QString, 36 },
        }}),
        // Slot 'unregister'
        QtMocHelpers::SlotData<bool(const QString &, const QString &)>(45, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 25 }, { QMetaType::QString, 46 },
        }}),
        // Slot 'blockGlobalShortcuts'
        QtMocHelpers::SlotData<void(bool)>(47, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'SetShortcutFlag'
        QtMocHelpers::EnumData<enum SetShortcutFlag>(48, 48, QMC::EnumFlags{}).add({
            {   49, SetShortcutFlag::SetPresent },
            {   50, SetShortcutFlag::NoAutoloading },
            {   51, SetShortcutFlag::IsDefault },
        }),
        // flag 'SetShortcutFlags'
        QtMocHelpers::EnumData<SetShortcutFlags>(52, 48, QMC::EnumIsFlag).add({
            {   49, SetShortcutFlag::SetPresent },
            {   50, SetShortcutFlag::NoAutoloading },
            {   51, SetShortcutFlag::IsDefault },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<KGlobalAccelD, qt_meta_tag_ZN13KGlobalAccelDE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KGlobalAccelD::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KGlobalAccelDE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KGlobalAccelDE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KGlobalAccelDE_t>.metaTypes,
    nullptr
} };

void KGlobalAccelD::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KGlobalAccelD *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->yourShortcutGotChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[2]))); break;
        case 1: _t->yourShortcutsChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSet<QKeySequence>>>(_a[2]))); break;
        case 2: { QList<QDBusObjectPath> _r = _t->allComponents();
            if (_a[0]) *reinterpret_cast<QList<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QList<QStringList> _r = _t->allMainComponents();
            if (_a[0]) *reinterpret_cast<QList<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QList<QStringList> _r = _t->allActionsForComponent((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QList<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QStringList _r = _t->action((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 6: { QStringList _r = _t->actionList((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 7: { QList<int> _r = _t->shortcut((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QList<int>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QSet<QKeySequence> _r = _t->shortcutKeys((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QSet<QKeySequence>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QList<int> _r = _t->defaultShortcut((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QList<int>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QSet<QKeySequence> _r = _t->defaultShortcutKeys((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QSet<QKeySequence>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusObjectPath _r = _t->getComponent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 12: { QList<int> _r = _t->setShortcut((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QList<int>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QSet<QKeySequence> _r = _t->setShortcutKeys((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSet<QKeySequence>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QSet<QKeySequence>*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->setForeignShortcut((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[2]))); break;
        case 15: _t->setForeignShortcutKeys((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSet<QKeySequence>>>(_a[2]))); break;
        case 16: _t->setInactive((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 17: _t->doRegister((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 18: _t->unRegister((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 19: _t->activateGlobalShortcutContext((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 20: { QList<KGlobalShortcutInfo> _r = _t->getGlobalShortcutsByKey((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QList<KGlobalShortcutInfo>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QList<KGlobalShortcutInfo> _r = _t->globalShortcutsByKey((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KGlobalAccel::MatchType>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QList<KGlobalShortcutInfo>*>(_a[0]) = std::move(_r); }  break;
        case 22: { bool _r = _t->isGlobalShortcutAvailable((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 23: { bool _r = _t->globalShortcutAvailable((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 24: { bool _r = _t->unregister((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->blockGlobalShortcuts((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KGlobalAccelD::*)(const QStringList & , const QList<int> & )>(_a, &KGlobalAccelD::yourShortcutGotChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGlobalAccelD::*)(const QStringList & , const QSet<QKeySequence> & )>(_a, &KGlobalAccelD::yourShortcutsChanged, 1))
            return;
    }
}

const QMetaObject *KGlobalAccelD::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KGlobalAccelD::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KGlobalAccelDE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QObject::qt_metacast(_clname);
}

int KGlobalAccelD::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    return _id;
}

// SIGNAL 0
void KGlobalAccelD::yourShortcutGotChanged(const QStringList & _t1, const QList<int> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void KGlobalAccelD::yourShortcutsChanged(const QStringList & _t1, const QSet<QKeySequence> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
QT_WARNING_POP
